P1-1 (phase 6): Subsystem modules.
Each renderer subsystem is a self-contained module. This
replaces the previous design where subsystem state was mixed
in with the rest of the renderer state in the giant
types.rs file.
Phase 6 of the P1-1 refactor: move the subsystem structs from
types.rs into their own files so they can be reviewed,
tested, and modified in isolation.
Re-exports
pub use config::RendererConfig;pub use gpu_capabilities::GpuCapabilities;pub use gpu_capabilities::GpuVendor;pub use gpu_capabilities::detect_gpu_vendor;pub use crate::types::GeometryBuffers;pub use crate::types::ParticleSubsystem;pub use crate::types::SvgSubsystem;pub use crate::types::TextSubsystem;
Modules
- config
- P1-1 (phase 6): RendererConfig – the renderer’s tunable parameters.
- geometry_
buffers - P1-1 (phase 6): GeometryBuffers – the three GPU draw buffers.
- gpu_
capabilities - P1-26: GPU capability detection.