PassNode

Trait PassNode 

pub trait PassNode:
    Send
    + Sync
    + 'static {
    // Provided methods
    fn id(&self) -> &'static str { ... }
    fn label(&self) -> &'static str { ... }
    fn inputs(&self) -> &[&'static str] { ... }
    fn outputs(&self) -> &[&'static str] { ... }
    fn pass_id(&self) -> KvasirId { ... }
}
Re-export PassNode for convenience. Trait for render pass nodes in the Kvasir graph. Implemented by pass nodes that want to participate in the frame graph.

Provided Methods

fn id(&self) -> &'static str

Unique identifier for this pass node type.

fn label(&self) -> &'static str

Human-readable label for debugging.

fn inputs(&self) -> &[&'static str]

Input resource names this pass consumes.

fn outputs(&self) -> &[&'static str]

Output resource names this pass produces.

fn pass_id(&self) -> KvasirId

Pass ID for scheduling (can be used to group passes).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors