docs.rs failed to build cvkg-render-gpu-0.1.16
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
cvkg-render-gpu-0.1.22
cvkg-render-gpu
cvkg-render-gpu (Project Surtr) is the primary high-performance GPU renderer for CVKG, built on wgpu.
🚀 Quick Start
use SurtrRenderer;
use ;
use View;