pub struct SurtrRenderer { /* private fields */ }Expand description
SurtrRenderer implements the high-performance GPU backend.
Implementations
Sourceimpl SurtrRenderer
impl SurtrRenderer
pub fn resize(&mut self, width: u32, height: u32)
Sourcepub fn begin_frame(&mut self) -> CommandEncoder
pub fn begin_frame(&mut self) -> CommandEncoder
begin_frame — Strike the flaming sword to begin a new GPU frame.
Sourcepub fn reset_time(&mut self)
pub fn reset_time(&mut self)
Reset the internal clock (for interactive effects)
Sourcepub fn end_frame(&mut self, encoder: CommandEncoder)
pub fn end_frame(&mut self, encoder: CommandEncoder)
end_frame — Quench the blade by submitting the full Muspelheim multi-pass effect.