pub struct SurtrRenderer { /* private fields */ }Expand description
SurtrRenderer implements the high-performance GPU backend.
Implementations
Sourceimpl SurtrRenderer
impl SurtrRenderer
Sourcepub fn begin_frame(&mut self) -> CommandEncoder
pub fn begin_frame(&mut self) -> CommandEncoder
begin_frame — Strike the flaming sword to begin a new GPU frame.
Sourcepub fn end_frame(&mut self, encoder: CommandEncoder)
pub fn end_frame(&mut self, encoder: CommandEncoder)
end_frame — Quench the blade by submitting the full Muspelheim multi-pass effect.