pub trait PassNode:
Send
+ Sync
+ 'static {
// Provided methods
fn id(&self) -> &'static str { ... }
fn label(&self) -> &'static str { ... }
fn inputs(&self) -> &[&'static str] { ... }
fn outputs(&self) -> &[&'static str] { ... }
fn pass_id(&self) -> KvasirId { ... }
}Expand description
Re-export PassNode for convenience. Trait for render pass nodes in the Kvasir graph. Implemented by pass nodes that want to participate in the frame graph.
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".